package com.supervision.manage.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import com.supervision.manage.service.FileManageService;
import com.supervision.model.FileResource;
import com.supervision.service.FileResourceService;
import com.supervision.util.MinioUtil;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.InputStream;

@Service
@RequiredArgsConstructor
public class FileManageServiceImpl implements FileManageService {

    private final FileResourceService fileResourceService;
    @Override
    public String uploadFile(MultipartFile multipartFile, String contentType) throws Exception {
        // 把文件上传到minio
        String minoId = MinioUtil.uploadFile(multipartFile.getInputStream(), contentType);

        //设置文件信息
        FileResource fileResource = new FileResource();
        fileResource.setFileName(multipartFile.getOriginalFilename());
        fileResource.setFileSize(multipartFile.getSize());
        fileResource.setMinioId(minoId);
        fileResource.setFileType(contentType);
        fileResourceService.save(fileResource);

        return fileResource.getId();
    }

    @Override
    public void downloadFile(String fileId, HttpServletResponse response) throws Exception {
        Assert.notEmpty(fileId, "文件id不能为空");

        FileResource fileResource = fileResourceService.getById(fileId);
        Assert.notNull(fileResource, "文件不存在");

        try (InputStream inputStream = MinioUtil.download(fileResource.getMinioId());
             ServletOutputStream outputStream = response.getOutputStream()){
            if (StrUtil.isNotEmpty(fileResource.getFileType())){
                response.setContentType(fileResource.getFileType());
            }

            byte[] bytes = new byte[1024];
            int len;
            while ((len = inputStream.read(bytes))!= -1){
                outputStream.write(bytes, 0, len);
            }
            outputStream.flush();
        }
    }
}
